#!/usr/bin/env perl
use warnings;
use strict;
require 5.008;

# Simply checks if we have all required libs, add whatever modules you
# use below:

use XAO::Web 1.06;

1;
